/*
 * This file is part of unity-2d
 *
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import QtQuick 1.1
import Effects 1.0
import "../common"

Item {
    id: shortcutHintOverlay
    objectName: "shortcutHintOverlay"
    width: 950
    height: 660
    focus: true

    BorderImage {
        id: border
        smooth: true
        anchors.fill: parent
        border { left: 20; top: 20; right: 20; bottom: 20 }
        source: "artwork/shortcut_hint_borders.png"
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
    }

    /*  Note: ListElement: cannot use script for property value
        So we can't use u2d.tr for display text directly.
        Workaround for QML bug : https://bugreports.qt-project.org/browse/QTBUG-16289
    */
    property list<ModelElement> leftColumnModel: [
        ModelElement { sectionId: "launcher"; description: u2d.tr("Launcher") },
        ModelElement { sectionId: "dash"; description: u2d.tr("Dash") },
        ModelElement { sectionId: "topBar"; description: u2d.tr("Top Bar") }
    ]

    property list<ModelElement> rightColumnModel: [
        ModelElement { sectionId: "switching"; description: u2d.tr("Switching") },
        ModelElement { sectionId: "workspaces"; description: u2d.tr("Workspaces") },
        ModelElement { sectionId: "windows"; description: u2d.tr("Windows") }
    ]

    property list<ModelElement> launcherModel: [
        ModelElement { defaultKey: "Super (Press)"; description: u2d.tr("Open Launcher, displays shortcuts."); gconfKey: "" },
        ModelElement { defaultKey: "Alt + F1"; description: u2d.tr("Open Launcher keyboard navigation mode."); gconfKey: "" },
        ModelElement { defaultKey: "Super + Tab"; description: u2d.tr("Switch applications via Launcher."); gconfKey: ""},
        ModelElement { defaultKey: "Super + 1 to 9"; description: u2d.tr("Same as clicking on a Launcher icon."); gconfKey: "" },
        ModelElement { defaultKey: "Super + Shift + 1 to 9"; description: u2d.tr("Open new window of the app."); gconfKey: "" },
        ModelElement { defaultKey: "Super + T"; description: u2d.tr("Open the Rubbish Bin."); gconfKey: "" }
    ]

    property list<ModelElement> dashModel: [
        ModelElement { defaultKey: "Super (Tap)"; description: u2d.tr("Open the Dash home."); gconfKey: "" },
        ModelElement { defaultKey: "Super + A"; description: u2d.tr("Open the Dash App Lens."); gconfKey: "" },
        ModelElement { defaultKey: "Super + F"; description: u2d.tr("Open the Dash Files Lens."); gconfKey: "" },
        ModelElement { defaultKey: "Super + M"; description: u2d.tr("Open the Dash Files Music."); gconfKey: "" },
        ModelElement { defaultKey: "Ctrl + Tab"; description: u2d.tr("Switches between Lenses."); gconfKey: "" },
        ModelElement { defaultKey: "Cursors Keys"; description: u2d.tr("Moves the focus."); gconfKey: "" },
        ModelElement { defaultKey: "Enter / Return"; description: u2d.tr("Open currently focused item."); gconfKey: "" },
        ModelElement { defaultKey: "Alt + F2"; description: u2d.tr("'Run Command' mode."); gconfKey: "" }
    ]

    property list<ModelElement> topBarModel: [
        ModelElement { defaultKey: "Alt"; description: u2d.tr("Reveals application menu."); gconfKey: "" },
        ModelElement { defaultKey: "Alt + F10"; description: u2d.tr("Open the indicator menu."); gconfKey: "" },
        ModelElement { defaultKey: "Cursor Left & Right"; description: u2d.tr("Moves focus between indicators."); gconfKey: ""  }
    ]

    property list<ModelElement> switchingModel: [
        ModelElement { defaultKey: "Alt + Tab"; description: u2d.tr("Switch between applications."); gconfKey: "/apps/metacity/global_keybindings/switch_windows" },
        ModelElement { defaultKey: "Alt + Grave"; description: u2d.tr("Switch windows of current application."); gconfKey: "/apps/metacity/global_keybindings/cycle_group" },
        ModelElement { defaultKey: "Cursor Up"; description: u2d.tr("Close window switch, return to app switch."); gconfKey: "" },
        ModelElement { defaultKey: "Cursor Left & Right"; description: u2d.tr("Moves the focus."); gconfKey: "" }
    ]

    property list<ModelElement> workspacesModel: [
        ModelElement { defaultKey: "Super + S"; description: u2d.tr("Spread workspaces."); gconfKey: "" },
        ModelElement { defaultKey: "Super + Cursors"; description: u2d.tr("Switch workspaces."); gconfKey: "/apps/metacity/global_keybindings/;switch_to_workspace_down;switch_to_workspace_up;switch_to_workspace_left;switch_to_workspace_right" },
        ModelElement { defaultKey: "Super + Alt + Cursors"; description: u2d.tr("Move focused window to other workspace."); gconfKey: "/apps/metacity/window_keybindings/;move_to_workspace_down;move_to_workspace_left;move_to_workspace_right;move_to_workspace_up" }
    ]

    property list<ModelElement> windowModel: [
        ModelElement { defaultKey: "Super + W"; description: u2d.tr("Spreads all windows in the current workspace."); gconfKey: "" },
        ModelElement { defaultKey: "Super + D"; description: u2d.tr("Minimizes all windows."); gconfKey: "/apps/metacity/global_keybindings/show_desktop" },
        ModelElement { defaultKey: "Alt + Space"; description: u2d.tr("Opens window accessibility menu."); gconfKey: "/apps/metacity/window_keybindings/activate_window_menu" },
        ModelElement { defaultKey: "Alt + F10"; description: u2d.tr("Maximizes or un-maximizes current window."); gconfKey: "/apps/metacity/window_keybindings/toggle_maximized" },
        ModelElement { defaultKey: "Alt + F9"; description: u2d.tr("Minimizes current window."); gconfKey: "/apps/metacity/window_keybindings/minimize" },
        ModelElement { defaultKey: "Alt + F8"; description: u2d.tr("Resizes current window."); gconfKey: "/apps/metacity/window_keybindings/begin_resize" },
        ModelElement { defaultKey: "Alt + F4"; description: u2d.tr("Closes current window."); gconfKey: "/apps/metacity/window_keybindings/close" },
        ModelElement { defaultKey: "Ctrl + Alt + Num"; description: u2d.tr("Places window in corresponding positions."); gconfKey: "/apps/metacity/window_keybindings/;move_to_corner_ne;move_to_corner_nw;move_to_corner_se;move_to_corner_sw;move_to_side_e;move_to_side_n;move_to_side_s;move_to_side_w" },
        ModelElement { defaultKey: "Alt + Left Mouse Drag"; description: u2d.tr("Move window."); gconfKey: "" },
        ModelElement { defaultKey: "Alt + Middle Mouse Drag"; description: u2d.tr("Resize window."); gconfKey: "" }
    ]

    Rectangle {
        id: totalArea
        color: "#00000000"
        radius: 8
        smooth: true
        anchors.fill: parent
        anchors.margins: 12
        clip: true

        Item {
            anchors.fill: parent
            clip: true

            Image {
                id: blurredBackground
                effect: Blur {}
                source: "image://window/root"
                fillMode: Image.PreserveAspectCrop
                cache: false
                x: -blurredBackground.mapToItem(null, 0, 0).x-totalArea.anchors.leftMargin
                y: -blurredBackground.mapToItem(null, 0, 0).y-totalArea.anchors.topMargin-declarativeView.screen.availableGeometry.y
            }

            Rectangle {
                anchors.fill: parent
                color: "#000000"
                opacity: 0.70
            }
        }

        Item {
            id: headerArea
            y: 0
            height: 75
            anchors.left: parent.left
            anchors.right: parent.right
            smooth: false

            TextCustom {
                id: title
                x: 350
                y: 25
                text: u2d.tr("Keyboard Shortcuts")
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 22
                anchors.horizontalCenterOffset: 0
                verticalAlignment: Text.AlignTop
                anchors.horizontalCenter: parent.horizontalCenter
                smooth: true
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                fontSize: "x-large"
            }
        }

        Item {
            id: contentsArea
            anchors.top: headerArea.bottom
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.rightMargin: 20

            Rectangle {
                id: topDivider
                width: 200
                height: 1
                color: "#ffffff"
                opacity: 0.2
                smooth: true
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
            }

            Item {
                id: contentLeft
                anchors.left: parent.left
                anchors.right: contentCenter.left
                anchors.top: topDivider.bottom
                anchors.bottom: parent.bottom

                Column {
                    id: leftColumn
                    Repeater {
                        model: leftColumnModel
                        ShortcutHintSection {}
                    }
                }
            }

            Item {
                id: contentCenter
                x: 438
                width: 40
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Item {
                id: contentRight
                x: 445
                y: 0
                width: 445
                anchors.left: contentCenter.right
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.bottom: parent.bottom

                Column {
                    id: rightColumn
                    Repeater {
                        model: rightColumnModel
                        ShortcutHintSection {}
                    }
                }
            }
        }
    }
}
