/*
 * This file is part of unity-2d
 *
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import QtQuick 1.0
import "../common"

Item {
    id: shortcutHitSection
    width: 430
    height: list.height + sectionTitle.height + sectionTitle.y + bottomSpacing.height + divider.height

    // It is decided by design, that certain keys having multiple values in gconf,
    // like 'Switch workspaces' should only be displayed when the keys are symmetric.
    function symmetricKey( gconfKey ) {
        var gconfKeys = gconfKey.split(";");
        var previousModifier = ""
        var count = gconfKeys.length
        var gconfKey_base = gconfKeys[0]
        for (var i = 1; i < count; i++) {
            var gconfItem = Qt.createQmlObject('import QtQuick 1.0; import gconf 0.1; GConfItem {}', shortcutHintOverlay);
            gconfItem.key = gconfKey_base+gconfKeys[i]
            var gconfValue = String(gconfItem.value) 
            var modifier = gconfValue.substring(0,gconfValue.lastIndexOf(">")+1)
            var key = gconfValue.substring(gconfValue.lastIndexOf(">")+1)
            if (previousModifier == "") {
                previousModifier = gconfValue.substring(0,gconfValue.lastIndexOf(">")+1)
                continue
            }  else {
                if (modifier != previousModifier) {
                    return ""
                }
            }
        }

        if (key.toLowerCase().indexOf("kp") == 0){
            previousModifier = previousModifier + "Num"
        } else {
            previousModifier = previousModifier + "Cursors"
        }

        return previousModifier;
    }

    Component {
        id: itemDelegate
        Item {
            anchors.right: parent.right
            anchors.left: parent.left

            function getShortcutKey() {
                if (model.modelData.gconfKey === "") {
                    return model.modelData.defaultKey;
                }

                var key = ""
                // Check is symmetric
                if (gconfKey.indexOf(";") != -1) {
                    key = symmetricKey(gconfKey);
                    if (key == "") {
                        return ""
                    }
                } else {
                    var gconfItem = Qt.createQmlObject('import QtQuick 1.0; import gconf 0.1; GConfItem {}', shortcutHintOverlay);
                    gconfItem.key = gconfKey
                    key = gconfItem.value
                }

                key = String(key)
                if (key === "") {
                    return model.modelData.defaultKey
                }
                key = key.replace(new RegExp( "<Control>", 'gi' ), "Ctrl + ")
                key = key.replace(new RegExp( "<Shift>", 'gi' ), "Shift + ")
                key = key.replace(new RegExp( "<Alt>", 'gi' ), "Alt + ")
                key = key.replace(new RegExp( "<Mod4>", 'gi' ), "Super + ")
                key = key.replace(new RegExp( "<Super>", 'gi' ), "Super + ")
                key = key.replace( /(^|\s)([a-z])/g , function(m,p1,p2){ return p1+p2.toUpperCase(); } );
                return key
            }

            Item {
                id: key
                anchors.left: parent.left
                anchors.leftMargin: 0
                width: 150
                TextCustom { id: keyText; text: getShortcutKey(); fontSize: "small" }
            }

            Item {
                id: spacing
                anchors.left: key.right
                width: 10
            }

            Item {
                id: value
                width: 265
                anchors.left: spacing.right
                TextCustom { text: model.modelData.description; fontSize: "small" }
            }
        }
    }

    TextCustom {
        id: sectionTitle
        y: 27
        text: model.modelData.description
        anchors.left: parent.left
        font.bold: true
        fontSize: "large"
    }

    ListView {
        id: list
        model: {
            if (sectionId == "launcher") return launcherModel
            else if (sectionId == "dash") return dashModel
            else if (sectionId == "topBar") return topBarModel
            else if (sectionId == "switching") return switchingModel
            else if (sectionId == "workspaces") return workspacesModel
            else if (sectionId == "windows") return windowModel
            else return ""
        }
        spacing: 18
        anchors.left: parent.left
        anchors.top: sectionTitle.bottom
        anchors.topMargin: 14
        height: (spacing * count) + anchors.topMargin
        delegate: itemDelegate
    }

    Item {
        id: bottomSpacing
        height: 20
    }

    Rectangle {
        id: divider
        height: 1
        color: "#ffffff"
        smooth: true
        anchors.top: shortcutHitSection.bottom
        anchors.right: parent.right
        anchors.left: parent.left
        opacity: 0.2
        visible: (index != 2)
    }
}
