#!/usr/bin/env ruby1.8
=begin
/*
 * This file is part of unity-2d
 *
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
=end

require '../run-tests.rb' unless $INIT_COMPLETED
require 'xdo/xwindow'
require 'xdo/keyboard'

############################# Test Suite #############################
context "Launcher Shortcut hint overlay Tests" do
  # Run once at the beginning of this test suite
  startup do
    $SUT.execute_shell_command 'killall unity-2d-shell'
    $SUT.execute_shell_command 'killall unity-2d-shell'

    # Minimize all windows
    XDo::XWindow.toggle_minimize_all
  end

  # Run once at the end of this test suite
  shutdown do
  end

  # Run before each test case begins
  setup do
    # Execute the application
    @app = $SUT.run( :name => UNITY_2D_SHELL,
                     :arguments => "-testability",
                     :sleeptime => 2 )
    # Make certain application is ready for testing
    verify{ @app.Launcher() }
  end

  # Run after each test case completes
  teardown do
    $SUT.execute_shell_command 'pkill -nf unity-2d-shell'
  end

  #####################################################################################
  # Test cases
    # Test case objectives:
    #   * Check shortcut hint overlay display/close
    # Pre-conditions
    #   * None
    # Test steps
    #   * Hold super key
    #   * Check the shortcut hint overlay is displayed
    #   * Release super key
    #   * Check that shortcut hint overlay is closed
    # Post-conditions
    #   * None
    # References
    #   * lp:#855532
  test "Check shortcut hint overlay display/close" do
    # Check the hint window is not displayed initially
    verify_not(TIMEOUT, 'Shortcut hint overlay should be closed, but visible') {
        @app.ShellDeclarativeView().ShortcutHint();
    }

    XDo::Keyboard.key_down('SUPER')
    # Check the hint window is displayed when 'super' is pressed
    verify(TIMEOUT, 'Shortcut hint overlay should be displayed, but it is not') {
        @app.ShellDeclarativeView().ShortcutHint();
    }

    XDo::Keyboard.key_up('SUPER')
    # Check the hint window is closed when 'super' is released
    verify_not(TIMEOUT, 'Shortcut hint overlay should be closed, but visible') {
        @app.ShellDeclarativeView().ShortcutHint();
    }
  end
end
